pub enum TMFError {
NoConnection(String),
Unknown(String),
Serialization(String),
}Expand description
TMF Error
Variants
NoConnection(String)
NoConnection Error when making a request to the TMF API
Unknown(String)
Unknown Error when making a request to the TMF API
Serialization(String)
Serialization Error when serializing or deserializing a TMF object